@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,31 +13,31 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
+from distutils import util
 import os
 import re
-from typing import Callable, Dict, Sequence, Tuple, Type, Union
+from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import client_options as client_options_lib  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-from google.api_core import operation
-from google.api_core import operation_async
+from google.api_core import operation  # type: ignore
+from google.api_core import operation_async  # type: ignore
 from google.cloud.gaming_v1.services.game_server_configs_service import pagers
 from google.cloud.gaming_v1.types import common
 from google.cloud.gaming_v1.types import game_server_configs
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
-from .transports.base import GameServerConfigsServiceTransport
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from .transports.base import GameServerConfigsServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import GameServerConfigsServiceGrpcTransport
 from .transports.grpc_asyncio import GameServerConfigsServiceGrpcAsyncIOTransport
 
@@ -60,7 +59,7 @@ class GameServerConfigsServiceClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[GameServerConfigsServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -85,7 +84,8 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -117,10 +117,27 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            GameServerConfigsServiceClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -129,7 +146,7 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            GameServerConfigsServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -137,32 +154,102 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
 
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> GameServerConfigsServiceTransport:
+        """Returns the transport used by the client instance.
+
+        Returns:
+            GameServerConfigsServiceTransport: The transport used by the client
+                instance.
+        """
+        return self._transport
+
     @staticmethod
     def game_server_config_path(
         project: str, location: str, deployment: str, config: str,
     ) -> str:
-        """Return a fully-qualified game_server_config string."""
+        """Returns a fully-qualified game_server_config string."""
         return "projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}".format(
             project=project, location=location, deployment=deployment, config=config,
         )
 
     @staticmethod
     def parse_game_server_config_path(path: str) -> Dict[str, str]:
-        """Parse a game_server_config path into its component segments."""
+        """Parses a game_server_config path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/gameServerDeployments/(?P<deployment>.+?)/configs/(?P<config>.+?)$",
             path,
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def common_billing_account_path(billing_account: str,) -> str:
+        """Returns a fully-qualified billing_account string."""
+        return "billingAccounts/{billing_account}".format(
+            billing_account=billing_account,
+        )
+
+    @staticmethod
+    def parse_common_billing_account_path(path: str) -> Dict[str, str]:
+        """Parse a billing_account path into its component segments."""
+        m = re.match(r"^billingAccounts/(?P<billing_account>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_folder_path(folder: str,) -> str:
+        """Returns a fully-qualified folder string."""
+        return "folders/{folder}".format(folder=folder,)
+
+    @staticmethod
+    def parse_common_folder_path(path: str) -> Dict[str, str]:
+        """Parse a folder path into its component segments."""
+        m = re.match(r"^folders/(?P<folder>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_organization_path(organization: str,) -> str:
+        """Returns a fully-qualified organization string."""
+        return "organizations/{organization}".format(organization=organization,)
+
+    @staticmethod
+    def parse_common_organization_path(path: str) -> Dict[str, str]:
+        """Parse a organization path into its component segments."""
+        m = re.match(r"^organizations/(?P<organization>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_project_path(project: str,) -> str:
+        """Returns a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
+
+    @staticmethod
+    def parse_common_project_path(path: str) -> Dict[str, str]:
+        """Parse a project path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_location_path(project: str, location: str,) -> str:
+        """Returns a fully-qualified location string."""
+        return "projects/{project}/locations/{location}".format(
+            project=project, location=location,
+        )
+
+    @staticmethod
+    def parse_common_location_path(path: str) -> Dict[str, str]:
+        """Parse a location path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
+        return m.groupdict() if m else {}
+
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
-        transport: Union[str, GameServerConfigsServiceTransport] = None,
-        client_options: ClientOptions = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        transport: Union[str, GameServerConfigsServiceTransport, None] = None,
+        client_options: Optional[client_options_lib.ClientOptions] = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the game server configs service client.
+        """Instantiates the game server configs service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -170,51 +257,76 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.GameServerConfigsServiceTransport]): The
+            transport (Union[str, GameServerConfigsServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (ClientOptions): Custom options for the client. It
-                won't take effect if a ``transport`` instance is provided.
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
-                default endpoint provided by the client. GOOGLE_API_USE_MTLS
+                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
                 "always" (always use the default mTLS endpoint), "never" (always
-                use the default regular endpoint, this is the default value for
-                the environment variable) and "auto" (auto switch to the default
-                mTLS endpoint if client SSL credentials is present). However,
-                the ``api_endpoint`` property takes precedence if provided.
-                (2) The ``client_cert_source`` property is used to provide client
-                SSL credentials for mutual TLS transport. If not provided, the
-                default SSL credentials will be used if present.
+                use the default regular endpoint) and "auto" (auto switch to the
+                default mTLS endpoint if client certificate is present, this is
+                the default value). However, the ``api_endpoint`` property takes
+                precedence if provided.
+                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
+                is "true", then the ``client_cert_source`` property can be used
+                to provide client certificate for mutual TLS transport. If
+                not provided, the default SSL client certificate will be used if
+                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
+                set, no client certificate will be used.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
+                your own client library.
 
         Raises:
             google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
         if isinstance(client_options, dict):
-            client_options = ClientOptions.from_dict(client_options)
+            client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
-            client_options = ClientOptions.ClientOptions()
+            client_options = client_options_lib.ClientOptions()
 
-        if client_options.api_endpoint is None:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS", "never")
+        # Create SSL credentials for mutual TLS if needed.
+        use_client_cert = bool(
+            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        )
+
+        client_cert_source_func = None
+        is_mtls = False
+        if use_client_cert:
+            if client_options.client_cert_source:
+                is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
+            else:
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        else:
+            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
             if use_mtls_env == "never":
-                client_options.api_endpoint = self.DEFAULT_ENDPOINT
+                api_endpoint = self.DEFAULT_ENDPOINT
             elif use_mtls_env == "always":
-                client_options.api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                has_client_cert_source = (
-                    client_options.client_cert_source is not None
-                    or mtls.has_default_client_cert_source()
-                )
-                client_options.api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT
-                    if has_client_cert_source
-                    else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -229,8 +341,8 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -238,10 +350,11 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
             self._transport = Transport(
                 credentials=credentials,
                 credentials_file=client_options.credentials_file,
-                host=client_options.api_endpoint,
+                host=api_endpoint,
                 scopes=client_options.scopes,
-                api_mtls_endpoint=client_options.api_endpoint,
-                client_cert_source=client_options.client_cert_source,
+                client_cert_source_for_mtls=client_cert_source_func,
+                quota_project_id=client_options.quota_project_id,
+                client_info=client_info,
             )
 
     def list_game_server_configs(
@@ -257,17 +370,17 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
         location, and game server deployment.
 
         Args:
-            request (:class:`~.game_server_configs.ListGameServerConfigsRequest`):
+            request (google.cloud.gaming_v1.types.ListGameServerConfigsRequest):
                 The request object. Request message for
                 GameServerConfigsService.ListGameServerConfigs.
-            parent (:class:`str`):
+            parent (str):
                 Required. The parent resource name. Uses the form:
 
                 ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -275,7 +388,7 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListGameServerConfigsPager:
+            google.cloud.gaming_v1.services.game_server_configs_service.pagers.ListGameServerConfigsPager:
                 Response message for
                 GameServerConfigsService.ListGameServerConfigs.
                 Iterating over this object will yield
@@ -286,27 +399,27 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
             )
 
-        request = game_server_configs.ListGameServerConfigsRequest(request)
-
-        # If we have keyword arguments corresponding to fields on the
-        # request, apply these.
-
-        if parent is not None:
-            request.parent = parent
+        # Minor optimization to avoid making a copy if the user passes
+        # in a game_server_configs.ListGameServerConfigsRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, game_server_configs.ListGameServerConfigsRequest):
+            request = game_server_configs.ListGameServerConfigsRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if parent is not None:
+                request.parent = parent
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
-        rpc = gapic_v1.method.wrap_method(
-            self._transport.list_game_server_configs,
-            default_timeout=None,
-            client_info=_client_info,
-        )
+        rpc = self._transport._wrapped_methods[self._transport.list_game_server_configs]
 
         # Certain fields should be provided within the metadata header;
         # add these here.
@@ -338,18 +451,18 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
         r"""Gets details of a single game server config.
 
         Args:
-            request (:class:`~.game_server_configs.GetGameServerConfigRequest`):
+            request (google.cloud.gaming_v1.types.GetGameServerConfigRequest):
                 The request object. Request message for
                 GameServerConfigsService.GetGameServerConfig.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the game server config to
                 retrieve. Uses the form:
 
                 ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -357,33 +470,33 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
                 sent along with the request as metadata.
 
         Returns:
-            ~.game_server_configs.GameServerConfig:
+            google.cloud.gaming_v1.types.GameServerConfig:
                 A game server config resource.
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
             )
 
-        request = game_server_configs.GetGameServerConfigRequest(request)
-
-        # If we have keyword arguments corresponding to fields on the
-        # request, apply these.
-
-        if name is not None:
-            request.name = name
+        # Minor optimization to avoid making a copy if the user passes
+        # in a game_server_configs.GetGameServerConfigRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, game_server_configs.GetGameServerConfigRequest):
+            request = game_server_configs.GetGameServerConfigRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
-        rpc = gapic_v1.method.wrap_method(
-            self._transport.get_game_server_config,
-            default_timeout=None,
-            client_info=_client_info,
-        )
+        rpc = self._transport._wrapped_methods[self._transport.get_game_server_config]
 
         # Certain fields should be provided within the metadata header;
         # add these here.
@@ -414,23 +527,24 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
         resource.
 
         Args:
-            request (:class:`~.game_server_configs.CreateGameServerConfigRequest`):
+            request (google.cloud.gaming_v1.types.CreateGameServerConfigRequest):
                 The request object. Request message for
                 GameServerConfigsService.CreateGameServerConfig.
-            parent (:class:`str`):
+            parent (str):
                 Required. The parent resource name. Uses the form:
 
                 ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            game_server_config (:class:`~.game_server_configs.GameServerConfig`):
+            game_server_config (google.cloud.gaming_v1.types.GameServerConfig):
                 Required. The game server config
                 resource to be created.
+
                 This corresponds to the ``game_server_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -438,40 +552,42 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.game_server_configs.GameServerConfig``: A
+                :class:`google.cloud.gaming_v1.types.GameServerConfig` A
                 game server config resource.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, game_server_config]):
+        has_flattened_params = any([parent, game_server_config])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
             )
 
-        request = game_server_configs.CreateGameServerConfigRequest(request)
-
-        # If we have keyword arguments corresponding to fields on the
-        # request, apply these.
-
-        if parent is not None:
-            request.parent = parent
-        if game_server_config is not None:
-            request.game_server_config = game_server_config
+        # Minor optimization to avoid making a copy if the user passes
+        # in a game_server_configs.CreateGameServerConfigRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, game_server_configs.CreateGameServerConfigRequest):
+            request = game_server_configs.CreateGameServerConfigRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if parent is not None:
+                request.parent = parent
+            if game_server_config is not None:
+                request.game_server_config = game_server_config
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
-        rpc = gapic_v1.method.wrap_method(
-            self._transport.create_game_server_config,
-            default_timeout=None,
-            client_info=_client_info,
-        )
+        rpc = self._transport._wrapped_methods[
+            self._transport.create_game_server_config
+        ]
 
         # Certain fields should be provided within the metadata header;
         # add these here.
@@ -507,18 +623,18 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
         game server deployment rollout.
 
         Args:
-            request (:class:`~.game_server_configs.DeleteGameServerConfigRequest`):
+            request (google.cloud.gaming_v1.types.DeleteGameServerConfigRequest):
                 The request object. Request message for
                 GameServerConfigsService.DeleteGameServerConfig.
-            name (:class:`str`):
+            name (str):
                 Required. The name of the game server config to delete.
                 Uses the form:
 
                 ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -526,50 +642,50 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation.Operation:
+            google.api_core.operation.Operation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
             )
 
-        request = game_server_configs.DeleteGameServerConfigRequest(request)
-
-        # If we have keyword arguments corresponding to fields on the
-        # request, apply these.
-
-        if name is not None:
-            request.name = name
+        # Minor optimization to avoid making a copy if the user passes
+        # in a game_server_configs.DeleteGameServerConfigRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, game_server_configs.DeleteGameServerConfigRequest):
+            request = game_server_configs.DeleteGameServerConfigRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
-        rpc = gapic_v1.method.wrap_method(
-            self._transport.delete_game_server_config,
-            default_timeout=None,
-            client_info=_client_info,
-        )
+        rpc = self._transport._wrapped_methods[
+            self._transport.delete_game_server_config
+        ]
 
         # Certain fields should be provided within the metadata header;
         # add these here.
@@ -584,7 +700,7 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=common.OperationMetadata,
         )
 
@@ -593,13 +709,13 @@ class GameServerConfigsServiceClient(metaclass=GameServerConfigsServiceClientMet
 
 
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
             "google-cloud-game-servers",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
 
 __all__ = ("GameServerConfigsServiceClient",)
