@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,16 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.cloud.gaming.v1beta",
+    package="google.cloud.gaming.v1",
     manifest={
         "OperationMetadata",
         "OperationStatus",
@@ -40,12 +37,11 @@ __protobuf__ = proto.module(
 
 class OperationMetadata(proto.Message):
     r"""Represents the metadata of the long-running operation.
-
     Attributes:
-        create_time (~.timestamp.Timestamp):
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time the operation was
             created.
-        end_time (~.timestamp.Timestamp):
+        end_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time the operation finished
             running.
         target (str):
@@ -69,7 +65,7 @@ class OperationMetadata(proto.Message):
         unreachable (Sequence[str]):
             Output only. List of Locations that could not
             be reached.
-        operation_status (Sequence[~.common.OperationMetadata.OperationStatusEntry]):
+        operation_status (Sequence[google.cloud.gaming_v1.types.OperationMetadata.OperationStatusEntry]):
             Output only. Operation status for Game
             Services API operations. Operation status is in
             the form of key-value pairs where keys are
@@ -78,22 +74,14 @@ class OperationMetadata(proto.Message):
             includes an error code and error message.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    target = proto.Field(proto.STRING, number=3)
-
-    verb = proto.Field(proto.STRING, number=4)
-
-    status_message = proto.Field(proto.STRING, number=5)
-
-    requested_cancellation = proto.Field(proto.BOOL, number=6)
-
-    api_version = proto.Field(proto.STRING, number=7)
-
-    unreachable = proto.RepeatedField(proto.STRING, number=8)
-
+    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    target = proto.Field(proto.STRING, number=3,)
+    verb = proto.Field(proto.STRING, number=4,)
+    status_message = proto.Field(proto.STRING, number=5,)
+    requested_cancellation = proto.Field(proto.BOOL, number=6,)
+    api_version = proto.Field(proto.STRING, number=7,)
+    unreachable = proto.RepeatedField(proto.STRING, number=8,)
     operation_status = proto.MapField(
         proto.STRING, proto.MESSAGE, number=9, message="OperationStatus",
     )
@@ -101,12 +89,11 @@ class OperationMetadata(proto.Message):
 
 class OperationStatus(proto.Message):
     r"""
-
     Attributes:
         done (bool):
             Output only. Whether the operation is done or
             still in progress.
-        error_code (~.common.OperationStatus.ErrorCode):
+        error_code (google.cloud.gaming_v1.types.OperationStatus.ErrorCode):
             The error code in case of failures.
         error_message (str):
             The human-readable error message.
@@ -119,33 +106,29 @@ class OperationStatus(proto.Message):
         PERMISSION_DENIED = 2
         CLUSTER_CONNECTION = 3
 
-    done = proto.Field(proto.BOOL, number=1)
-
+    done = proto.Field(proto.BOOL, number=1,)
     error_code = proto.Field(proto.ENUM, number=2, enum=ErrorCode,)
-
-    error_message = proto.Field(proto.STRING, number=3)
+    error_message = proto.Field(proto.STRING, number=3,)
 
 
 class LabelSelector(proto.Message):
     r"""The label selector, used to group labels on the resources.
-
     Attributes:
-        labels (Sequence[~.common.LabelSelector.LabelsEntry]):
+        labels (Sequence[google.cloud.gaming_v1.types.LabelSelector.LabelsEntry]):
             Resource labels for this selector.
     """
 
-    labels = proto.MapField(proto.STRING, proto.STRING, number=1)
+    labels = proto.MapField(proto.STRING, proto.STRING, number=1,)
 
 
 class RealmSelector(proto.Message):
     r"""The realm selector, used to match realm resources.
-
     Attributes:
         realms (Sequence[str]):
             List of realms to match.
     """
 
-    realms = proto.RepeatedField(proto.STRING, number=1)
+    realms = proto.RepeatedField(proto.STRING, number=1,)
 
 
 class Schedule(proto.Message):
@@ -156,18 +139,18 @@ class Schedule(proto.Message):
     specified, the event is effective starting at the local time
     specified by cron_spec, and is recurring.
 
-    :: 
+    ::
 
         start_time|-------[cron job]-------[cron job]-------[cron job]---|end_time
         cron job: cron spec start time + duration
 
 
     Attributes:
-        start_time (~.timestamp.Timestamp):
+        start_time (google.protobuf.timestamp_pb2.Timestamp):
             The start time of the event.
-        end_time (~.timestamp.Timestamp):
+        end_time (google.protobuf.timestamp_pb2.Timestamp):
             The end time of the event.
-        cron_job_duration (~.duration.Duration):
+        cron_job_duration (google.protobuf.duration_pb2.Duration):
             The duration for the cron job event. The
             duration of the event is effective after the
             cron job's start time.
@@ -178,13 +161,12 @@ class Schedule(proto.Message):
             realm.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    cron_job_duration = proto.Field(proto.MESSAGE, number=3, message=duration.Duration,)
-
-    cron_spec = proto.Field(proto.STRING, number=4)
+    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    cron_job_duration = proto.Field(
+        proto.MESSAGE, number=3, message=duration_pb2.Duration,
+    )
+    cron_spec = proto.Field(proto.STRING, number=4,)
 
 
 class SpecSource(proto.Message):
@@ -202,14 +184,12 @@ class SpecSource(proto.Message):
             or Agones autoscaler spec.
     """
 
-    game_server_config_name = proto.Field(proto.STRING, number=1)
-
-    name = proto.Field(proto.STRING, number=2)
+    game_server_config_name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(proto.STRING, number=2,)
 
 
 class TargetDetails(proto.Message):
     r"""Details about the Agones resources.
-
     Attributes:
         game_server_cluster_name (str):
             The game server cluster name. Uses the form:
@@ -219,68 +199,60 @@ class TargetDetails(proto.Message):
             The game server deployment name. Uses the form:
 
             ``projects/{project}/locations/{location}/gameServerDeployments/{deployment_id}``.
-        fleet_details (Sequence[~.common.TargetDetails.TargetFleetDetails]):
+        fleet_details (Sequence[google.cloud.gaming_v1.types.TargetDetails.TargetFleetDetails]):
             Agones fleet details for game server clusters
             and game server deployments.
     """
 
     class TargetFleetDetails(proto.Message):
         r"""Details of the target Agones fleet.
-
         Attributes:
-            fleet (~.common.TargetDetails.TargetFleetDetails.TargetFleet):
+            fleet (google.cloud.gaming_v1.types.TargetDetails.TargetFleetDetails.TargetFleet):
                 Reference to target Agones fleet.
-            autoscaler (~.common.TargetDetails.TargetFleetDetails.TargetFleetAutoscaler):
+            autoscaler (google.cloud.gaming_v1.types.TargetDetails.TargetFleetDetails.TargetFleetAutoscaler):
                 Reference to target Agones fleet autoscaling
                 policy.
         """
 
         class TargetFleet(proto.Message):
             r"""Target Agones fleet specification.
-
             Attributes:
                 name (str):
                     The name of the Agones fleet.
-                spec_source (~.common.SpecSource):
+                spec_source (google.cloud.gaming_v1.types.SpecSource):
                     Encapsulates the source of the Agones fleet
                     spec. The Agones fleet spec source.
             """
 
-            name = proto.Field(proto.STRING, number=1)
-
-            spec_source = proto.Field(proto.MESSAGE, number=2, message=SpecSource,)
+            name = proto.Field(proto.STRING, number=1,)
+            spec_source = proto.Field(proto.MESSAGE, number=2, message="SpecSource",)
 
         class TargetFleetAutoscaler(proto.Message):
             r"""Target Agones autoscaler policy reference.
-
             Attributes:
                 name (str):
                     The name of the Agones autoscaler.
-                spec_source (~.common.SpecSource):
+                spec_source (google.cloud.gaming_v1.types.SpecSource):
                     Encapsulates the source of the Agones fleet
                     spec. Details about the Agones autoscaler spec.
             """
 
-            name = proto.Field(proto.STRING, number=1)
-
-            spec_source = proto.Field(proto.MESSAGE, number=2, message=SpecSource,)
+            name = proto.Field(proto.STRING, number=1,)
+            spec_source = proto.Field(proto.MESSAGE, number=2, message="SpecSource",)
 
         fleet = proto.Field(
             proto.MESSAGE,
             number=1,
             message="TargetDetails.TargetFleetDetails.TargetFleet",
         )
-
         autoscaler = proto.Field(
             proto.MESSAGE,
             number=2,
             message="TargetDetails.TargetFleetDetails.TargetFleetAutoscaler",
         )
 
-    game_server_cluster_name = proto.Field(proto.STRING, number=1)
-
-    game_server_deployment_name = proto.Field(proto.STRING, number=2)
-
+    game_server_cluster_name = proto.Field(proto.STRING, number=1,)
+    game_server_deployment_name = proto.Field(proto.STRING, number=2,)
     fleet_details = proto.RepeatedField(
         proto.MESSAGE, number=3, message=TargetFleetDetails,
     )
@@ -288,40 +260,37 @@ class TargetDetails(proto.Message):
 
 class TargetState(proto.Message):
     r"""Encapsulates the Target state.
-
     Attributes:
-        details (Sequence[~.common.TargetDetails]):
+        details (Sequence[google.cloud.gaming_v1.types.TargetDetails]):
             Details about Agones fleets.
     """
 
-    details = proto.RepeatedField(proto.MESSAGE, number=1, message=TargetDetails,)
+    details = proto.RepeatedField(proto.MESSAGE, number=1, message="TargetDetails",)
 
 
 class DeployedFleetDetails(proto.Message):
     r"""Details of the deployed Agones fleet.
-
     Attributes:
-        deployed_fleet (~.common.DeployedFleetDetails.DeployedFleet):
+        deployed_fleet (google.cloud.gaming_v1.types.DeployedFleetDetails.DeployedFleet):
             Information about the Agones fleet.
-        deployed_autoscaler (~.common.DeployedFleetDetails.DeployedFleetAutoscaler):
+        deployed_autoscaler (google.cloud.gaming_v1.types.DeployedFleetDetails.DeployedFleetAutoscaler):
             Information about the Agones autoscaler for
             that fleet.
     """
 
     class DeployedFleet(proto.Message):
         r"""Agones fleet specification and details.
-
         Attributes:
             fleet (str):
                 The name of the Agones fleet.
             fleet_spec (str):
                 The fleet spec retrieved from the Agones
                 fleet.
-            spec_source (~.common.SpecSource):
+            spec_source (google.cloud.gaming_v1.types.SpecSource):
                 The source spec that is used to create the
                 Agones fleet. The GameServerConfig resource may
                 no longer exist in the system.
-            status (~.common.DeployedFleetDetails.DeployedFleet.DeployedFleetStatus):
+            status (google.cloud.gaming_v1.types.DeployedFleetDetails.DeployedFleet.DeployedFleetStatus):
                 The current status of the Agones fleet.
                 Includes count of game servers in various
                 states.
@@ -348,20 +317,14 @@ class DeployedFleetDetails(proto.Message):
                     replicas in this fleet.
             """
 
-            ready_replicas = proto.Field(proto.INT64, number=1)
-
-            allocated_replicas = proto.Field(proto.INT64, number=2)
-
-            reserved_replicas = proto.Field(proto.INT64, number=3)
-
-            replicas = proto.Field(proto.INT64, number=4)
-
-        fleet = proto.Field(proto.STRING, number=1)
-
-        fleet_spec = proto.Field(proto.STRING, number=2)
-
-        spec_source = proto.Field(proto.MESSAGE, number=3, message=SpecSource,)
+            ready_replicas = proto.Field(proto.INT64, number=1,)
+            allocated_replicas = proto.Field(proto.INT64, number=2,)
+            reserved_replicas = proto.Field(proto.INT64, number=3,)
+            replicas = proto.Field(proto.INT64, number=4,)
 
+        fleet = proto.Field(proto.STRING, number=1,)
+        fleet_spec = proto.Field(proto.STRING, number=2,)
+        spec_source = proto.Field(proto.MESSAGE, number=3, message="SpecSource",)
         status = proto.Field(
             proto.MESSAGE,
             number=5,
@@ -370,11 +333,10 @@ class DeployedFleetDetails(proto.Message):
 
     class DeployedFleetAutoscaler(proto.Message):
         r"""Details about the Agones autoscaler.
-
         Attributes:
             autoscaler (str):
                 The name of the Agones autoscaler.
-            spec_source (~.common.SpecSource):
+            spec_source (google.cloud.gaming_v1.types.SpecSource):
                 The source spec that is used to create the
                 autoscaler. The GameServerConfig resource may no
                 longer exist in the system.
@@ -382,14 +344,11 @@ class DeployedFleetDetails(proto.Message):
                 The autoscaler spec retrieved from Agones.
         """
 
-        autoscaler = proto.Field(proto.STRING, number=1)
-
-        spec_source = proto.Field(proto.MESSAGE, number=4, message=SpecSource,)
-
-        fleet_autoscaler_spec = proto.Field(proto.STRING, number=3)
+        autoscaler = proto.Field(proto.STRING, number=1,)
+        spec_source = proto.Field(proto.MESSAGE, number=4, message="SpecSource",)
+        fleet_autoscaler_spec = proto.Field(proto.STRING, number=3,)
 
     deployed_fleet = proto.Field(proto.MESSAGE, number=1, message=DeployedFleet,)
-
     deployed_autoscaler = proto.Field(
         proto.MESSAGE, number=2, message=DeployedFleetAutoscaler,
     )
