@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,17 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.gaming_v1.types import common
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.cloud.gaming.v1beta",
+    package="google.cloud.gaming.v1",
     manifest={
         "ListRealmsRequest",
         "ListRealmsResponse",
@@ -41,7 +38,6 @@ __protobuf__ = proto.module(
 
 class ListRealmsRequest(proto.Message):
     r"""Request message for RealmsService.ListRealms.
-
     Attributes:
         parent (str):
             Required. The parent resource name. Uses the form:
@@ -51,7 +47,7 @@ class ListRealmsRequest(proto.Message):
             unspecified, server will pick an appropriate default. Server
             may return fewer items than requested. A caller should only
             rely on response's
-            [next_page_token][google.cloud.gaming.v1beta.ListRealmsResponse.next_page_token]
+            [next_page_token][google.cloud.gaming.v1.ListRealmsResponse.next_page_token]
             to determine if there are more realms left to be queried.
         page_token (str):
             Optional. The next_page_token value returned from a previous
@@ -65,22 +61,17 @@ class ListRealmsRequest(proto.Message):
             https://cloud.google.com/apis/design/design_patterns#sorting_order.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    filter = proto.Field(proto.STRING, number=4)
-
-    order_by = proto.Field(proto.STRING, number=5)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    filter = proto.Field(proto.STRING, number=4,)
+    order_by = proto.Field(proto.STRING, number=5,)
 
 
 class ListRealmsResponse(proto.Message):
     r"""Response message for RealmsService.ListRealms.
-
     Attributes:
-        realms (Sequence[~.gcgv_realms.Realm]):
+        realms (Sequence[google.cloud.gaming_v1.types.Realm]):
             The list of realms.
         next_page_token (str):
             Token to retrieve the next page of results,
@@ -95,27 +86,23 @@ class ListRealmsResponse(proto.Message):
         return self
 
     realms = proto.RepeatedField(proto.MESSAGE, number=1, message="Realm",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
-
-    unreachable = proto.RepeatedField(proto.STRING, number=3)
+    next_page_token = proto.Field(proto.STRING, number=2,)
+    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class GetRealmRequest(proto.Message):
     r"""Request message for RealmsService.GetRealm.
-
     Attributes:
         name (str):
             Required. The name of the realm to retrieve. Uses the form:
             ``projects/{project}/locations/{location}/realms/{realm}``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class CreateRealmRequest(proto.Message):
     r"""Request message for RealmsService.CreateRealm.
-
     Attributes:
         parent (str):
             Required. The parent resource name. Uses the form:
@@ -123,37 +110,33 @@ class CreateRealmRequest(proto.Message):
         realm_id (str):
             Required. The ID of the realm resource to be
             created.
-        realm (~.gcgv_realms.Realm):
+        realm (google.cloud.gaming_v1.types.Realm):
             Required. The realm resource to be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    realm_id = proto.Field(proto.STRING, number=2)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    realm_id = proto.Field(proto.STRING, number=2,)
     realm = proto.Field(proto.MESSAGE, number=3, message="Realm",)
 
 
 class DeleteRealmRequest(proto.Message):
     r"""Request message for RealmsService.DeleteRealm.
-
     Attributes:
         name (str):
             Required. The name of the realm to delete. Uses the form:
             ``projects/{project}/locations/{location}/realms/{realm}``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateRealmRequest(proto.Message):
     r"""Request message for RealmsService.UpdateRealm.
-
     Attributes:
-        realm (~.gcgv_realms.Realm):
+        realm (google.cloud.gaming_v1.types.Realm):
             Required. The realm to be updated. Only fields specified in
             update_mask are updated.
-        update_mask (~.field_mask.FieldMask):
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
             Required. The update mask applies to the resource. For the
             ``FieldMask`` definition, see
 
@@ -162,64 +145,63 @@ class UpdateRealmRequest(proto.Message):
     """
 
     realm = proto.Field(proto.MESSAGE, number=1, message="Realm",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
 
 
 class PreviewRealmUpdateRequest(proto.Message):
     r"""Request message for RealmsService.PreviewRealmUpdate.
-
     Attributes:
-        realm (~.gcgv_realms.Realm):
+        realm (google.cloud.gaming_v1.types.Realm):
             Required. The realm to be updated. Only fields specified in
             update_mask are updated.
-        update_mask (~.field_mask.FieldMask):
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
             Required. The update mask applies to the resource. For the
             ``FieldMask`` definition, see
 
             https: //developers.google.com/protocol-buffers //
             /docs/reference/google.protobuf#fieldmask
-        preview_time (~.timestamp.Timestamp):
+        preview_time (google.protobuf.timestamp_pb2.Timestamp):
             Optional. The target timestamp to compute the
             preview.
     """
 
     realm = proto.Field(proto.MESSAGE, number=1, message="Realm",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask.FieldMask,)
-
-    preview_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
+    preview_time = proto.Field(
+        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+    )
 
 
 class PreviewRealmUpdateResponse(proto.Message):
     r"""Response message for RealmsService.PreviewRealmUpdate.
-
     Attributes:
         etag (str):
             ETag of the realm.
-        target_state (~.common.TargetState):
+        target_state (google.cloud.gaming_v1.types.TargetState):
             The target state.
     """
 
-    etag = proto.Field(proto.STRING, number=2)
-
+    etag = proto.Field(proto.STRING, number=2,)
     target_state = proto.Field(proto.MESSAGE, number=3, message=common.TargetState,)
 
 
 class Realm(proto.Message):
     r"""A realm resource.
-
     Attributes:
         name (str):
             The resource name of the realm. Uses the form:
             ``projects/{project}/locations/{location}/realms/{realm}``.
             For example,
             ``projects/my-project/locations/{location}/realms/my-realm``.
-        create_time (~.timestamp.Timestamp):
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The creation time.
-        update_time (~.timestamp.Timestamp):
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The last-modified time.
-        labels (Sequence[~.gcgv_realms.Realm.LabelsEntry]):
+        labels (Sequence[google.cloud.gaming_v1.types.Realm.LabelsEntry]):
             The labels associated with this realm. Each
             label is a key-value pair.
         time_zone (str):
@@ -233,19 +215,13 @@ class Realm(proto.Message):
             Human readable description of the realm.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4)
-
-    time_zone = proto.Field(proto.STRING, number=6)
-
-    etag = proto.Field(proto.STRING, number=7)
-
-    description = proto.Field(proto.STRING, number=8)
+    name = proto.Field(proto.STRING, number=1,)
+    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
+    time_zone = proto.Field(proto.STRING, number=6,)
+    etag = proto.Field(proto.STRING, number=7,)
+    description = proto.Field(proto.STRING, number=8,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
